from .fetch_swl_index_spot import sw_index_spot
from .fetch_sw_index_daily import sw_index_daily, sw_index_daily_indicator
from .fetch_sw_index_class import sw_index_class, sw_index_class_all
from .fetch_sw_index_cons import sw_index_cons, sw_index_legulegu_cons

